Returns the URL for the content dashboard (opened to the selected pane). NOTE: this takes a character object for performance optimization.
dashboard_url_chr(connect_url, content_guid, pane = "")character The dashboard URL for the content provided
character The base URL of the Connect server
character The guid for the content item in question
character The pane in the dashboard to link to
Other content functions:
acl_add_user(),
content_delete(),
content_item(),
content_title(),
content_update(),
create_random_name(),
dashboard_url(),
delete_vanity_url(),
deploy_repo(),
get_acl_user(),
get_bundles(),
get_environment(),
get_image(),
get_jobs(),
get_vanity_url(),
git,
permissions,
set_image_path(),
set_run_as(),
set_vanity_url(),
swap_vanity_url(),
verify_content_name()