| page_cursor | R Documentation |
Helper functions that make paging easier in the Posit Connect Server API.
page_cursor(client, req, limit = Inf)
page_offset(client, req, limit = Inf)
client |
A Connect client object |
req |
For page_cursor, the output from an initial response to an API endpoint that uses cursor-based pagination. For page_offset, a request that needs to be paged. |
limit |
A row limit |
The aggregated results from all requests
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.